# memrise-scraper

simple memrise scraper

## Usage:

### On Windows:
```
py -3 memrise.py /course/68063/topik-in-30-days-intermediate-vocabulary/  >output.csv
```

### On Linux:

```
python3 memrise.py /course/68063/topik-in-30-days-intermediate-vocabulary/ | sort -u
```

